/**
 * Contextly classes may load AFTER this file due to the lack of external JS
 * support on D6.
 */
(function ($) {

  Drupal.contextly = Drupal.contextly || {};

  /**
   * @class
   * @extends Contextly.BaseSettings
   */
  Drupal.contextly.settingsOverrides = {
    /**
     * @param key
     * @param [fallback]
     */
    getDrupalSetting: function(key, fallback) {
      if (!Drupal.settings.contextlyWidgets) {
        return fallback;
      }

      if (typeof Drupal.settings.contextlyWidgets[key] === 'undefined') {
        return fallback;
      }

      return Drupal.settings.contextlyWidgets[key];
    },

    /**
     * Returns API server URL.
     *
     * @function
     */
    getAPIServerUrl: function() {
      return this.getDrupalSetting('apiServerURL');
    },

    /**
     * Returns main Contextly server URL.
     *
     * @function
     */
    getMainServerUrl: function() {
      return this.getDrupalSetting('mainServerURL');
    },

    /**
     * Returns WP plug-in version.
     *
     * @todo Replace with Kit version and drop it.
     *
     * @function
     */
    getPluginVersion: function() {
      return this.getDrupalSetting('version');
    },

    /**
     * @function
     */
    getAppId: function() {
      return this.getDrupalSetting('appId');
    }
  };

  function applyOverrides() {
    Contextly.Settings = Contextly.createClass({
      extend: Contextly.BaseSettings,
      statics: Drupal.contextly.settingsOverrides
    });

    // Override page view method to control which widgets must be displayed.
    var original = Contextly.PageView.getDisplayableWidgetCollections;
    Contextly.PageView.getDisplayableWidgetCollections = function(response) {
      if (Contextly.Settings.getDrupalSetting('renderLinkWidgets')) {
        return original.apply(this, arguments);
      }
      else {
        // Still display storyline subscribe button on turned off link widgets.
        return [
          response.entry.storyline_subscribe
        ];
      }
    };
  }

  Drupal.behaviors.contextlyWidgets = function (context) {
    if (!Drupal.settings.contextlyWidgets) {
      return;
    }

    // Make sure we initialize widgets only once on the page.
    var markerClass = 'contextly-widgets-processed';
    var isFirstTime = $('body:not(.' + markerClass + ')', context)
      .addClass(markerClass)
      .size();
    if (!isFirstTime) {
      return;
    }

    // Get widget containers and make sure they're not empty.
    var containers = $('#ctx-module, .ctx-sidebar, #ctx-sl-subscribe', context);
    if (!containers.length) {
      return;
    }

    // Extend classes on DOM ready since Kit scripts may load after this file.
    applyOverrides();

    Contextly.load();
  };

})(jQuery);
